from django.contrib import admin


class CustomAutocompleteStackedMixin(admin.StackedInline):
	template = 'admin/django_grappelli_custom_autocomplete/edit_inline/stacked.html'

	class Media:        
		css = {
			"all": ('django_grappelli_custom_autocomplete/css/django-grappelli-custom-autocomplete.css',)
		}
		js = [
			'django_grappelli_custom_autocomplete/js/grp_custom_autocomplete_functions.js',
			'django_grappelli_custom_autocomplete/js/jquery.grp_custom_autocomplete_fk.js',
			'django_grappelli_custom_autocomplete/js/jquery.grp_custom_autocomplete_generic.js',
			'django_grappelli_custom_autocomplete/js/jquery.grp_custom_autocomplete_m2m.js',
		]


class CustomAutocompleteTabularMixin(admin.TabularInline):
	template = 'admin/django_grappelli_custom_autocomplete/edit_inline/tabular.html'

	class Media:        
		css = {
			"all": ('django_grappelli_custom_autocomplete/css/django-grappelli-custom-autocomplete.css',)
		}
		js = [
			'django_grappelli_custom_autocomplete/js/grp_custom_autocomplete_functions.js',
			'django_grappelli_custom_autocomplete/js/jquery.grp_custom_autocomplete_fk.js',
			'django_grappelli_custom_autocomplete/js/jquery.grp_custom_autocomplete_generic.js',
			'django_grappelli_custom_autocomplete/js/jquery.grp_custom_autocomplete_m2m.js',
		]

class CustomAutocompleteMixin(admin.ModelAdmin):
	change_form_template = 'admin/django_grappelli_custom_autocomplete/change_form.html'

	class Media:        
		css = {
			"all": ('django_grappelli_custom_autocomplete/css/django-grappelli-custom-autocomplete.css',)
		}
		js = [
			'django_grappelli_custom_autocomplete/js/grp_custom_autocomplete_functions.js',
			'django_grappelli_custom_autocomplete/js/jquery.grp_custom_autocomplete_fk.js',
			'django_grappelli_custom_autocomplete/js/jquery.grp_custom_autocomplete_generic.js',
			'django_grappelli_custom_autocomplete/js/jquery.grp_custom_autocomplete_m2m.js',
		]




# coding: utf-8

# python imports
from functools import wraps
import json

try:
    from django.contrib.auth import get_user_model
    User = get_user_model()
except ImportError:
    from django.contrib.auth.models import User

# django imports
from django import template
from django.contrib.contenttypes.models import ContentType
from django.utils.formats import get_format
from django.utils.safestring import mark_safe
from django.utils.translation import get_language
from django.template.loader import get_template
from django.template.context import Context
from django.utils.translation import ugettext as _

# grappelli imports
from grappelli.settings import ADMIN_TITLE, ADMIN_URL, SWITCH_USER, SWITCH_USER_ORIGINAL, SWITCH_USER_TARGET, CLEAN_INPUT_TYPES
from grappelli.templatetags.grp_tags import safe_json_else_list_tag

register = template.Library()


# GENERIC OBJECTS
class do_get_generic_objects(template.Node):
    def __init__(self):
        pass

    def render(self, context):
        objects = {}
        for c in ContentType.objects.all().order_by('id'):
            objects[c.id] = {'pk': c.id, 'app': c.app_label, 'model': c.model}
        return json.dumps(objects)

# AUTOCOMPLETES

@register.assignment_tag()
def get_custom_autocomplete_lookup_fields_fk(model_admin):
    if getattr(model_admin, "custom_autocomplete_lookup_fields", None):
        return model_admin.custom_autocomplete_lookup_fields.get("fk", [])
    return []


@register.assignment_tag()
def get_custom_autocomplete_lookup_fields_m2m(model_admin):
    if getattr(model_admin, "custom_autocomplete_lookup_fields", None):
        return model_admin.custom_autocomplete_lookup_fields.get("m2m", [])
    return []


@register.assignment_tag()
def get_custom_autocomplete_lookup_fields_generic(model_admin):
    if getattr(model_admin, "custom_autocomplete_lookup_fields", None):
        return model_admin.custom_autocomplete_lookup_fields.get("generic", [])
    return []




from setuptools import setup, find_packages
#this is a test
setup(name = 'django-grappelli-custom-autocomplete',
      description = 'Customize the template for autocomplete lookups.',
      version = '1.3',
      url = 'https://github.com/ninapavlich/django-grappelli-custom-autocomplete',
      author = 'Nina Pavlich',
      author_email='nina@ninalp.com',
      license = 'BSD',
      packages=find_packages(),
      package_data={'': ['*.py','*.css','*.js']},
      include_package_data=True,
      install_requires = [],
      classifiers=[
            'Development Status :: 4 - Beta',
            'Environment :: Web Environment',
            'Framework :: Django',
            'Intended Audience :: Developers',
            'License :: OSI Approved',
            'Operating System :: OS Independent',
            'Programming Language :: Python'
      ]
)
